package org.rcisoft.business.bspace.controller;


/*固定导入*/

import com.alibaba.fastjson.JSON;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.bspace.entity.BSpace;
import org.rcisoft.business.bspace.service.BSpaceService;
import org.rcisoft.config.CySecurityConfig;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.sys.user.entity.SysUser;
import org.rcisoft.sys.user.service.SysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * Created by  on 2018-6-21 17:10:54.
 */
@RestController
@RequestMapping("bspace")
@Slf4j
public class BSpaceController extends CyPaginationController<BSpace> {

    @Autowired
    private BSpaceService bSpaceServiceImpl;

    @Autowired
    private SysUserService userServiceImpl;
    @Autowired
    private CySecurityConfig cySecurityConfig;

    @GetMapping(value = "/num")
    @ApiOperation(value = "查看  集合 不分页", notes = "查看  集合")
    public CyResult lists(BSpace bSpace) {
//        return CyResultGenUtil.builder(new CyPersistModel(1),
//                CyMessCons.MESSAGE_ALERT_SUCCESS,
//                CyMessCons.MESSAGE_ALERT_ERROR,cySecurityConfig.httpStr());

        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,bSpaceServiceImpl.listAllSpaces(bSpace));
    }
    /**
     * 查询空间  分页
     *
     * @param spaceList
     * @return
     */
    @ApiOperation(value="分页查询空间", notes="分页查询空间")
    @GetMapping(value = "/querySpaceListsByPagination")
    public CyGridModel querySpaceListsByPagination(BSpace spaceList){
        bSpaceServiceImpl.querySpaceListsByPagination(getPaginationUtility(),spaceList);
        CyGridModel CyGridModel = getGridModelResponse();
        return CyGridModel;
    }
    /**
     * 增加/修改空间
     *
     * @param spaceList
     * @return
     */
    @ApiOperation(value = "增加/修改空间", notes = "增加/修改空间")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "spaceName", value = "空间名称", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "spaceId", value = "空间编号", required = true, dataType = "varchar")})
    @PostMapping(value = "/spaceAdd")
    public CyResult spaceAdd(BSpace spaceList) {
        int line = bSpaceServiceImpl.persistSpaceList(spaceList,getToken());
        return CyResultGenUtil.builder(new CyPersistModel(line),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                spaceList);
    }

    /**
     * 通过businessId查询
     * @param businessId
     * @return
     */
    @ApiOperation(value="根据Id查询数据", notes="根据Id查询数据")
    @ApiImplicitParam(name = "businessId", value = "空间的businessId", required = true, dataType = "varchar")
    @GetMapping(value = "/querySpaceListByBusinessId")
    public CyResult querySpaceListByBusinessId(String businessId){
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bSpaceServiceImpl.querySpaceListByBusinessId(businessId));

    }

    @ApiOperation(value="查询空间数", notes="查询空间数")
    @GetMapping(value = "/querySpaceNum")
    public CyResult querySpaceNum(BSpace spaceList){
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bSpaceServiceImpl.querySpaceNum(spaceList));
    }


    @ApiOperation(value = "逻辑删除", notes = "逻辑删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "id", required = false, dataType = "varchar")})
    @PostMapping("/LogicalDelete")
    public CyResult delete(String businessId) {
        BSpace bspqce = new BSpace();
        bspqce.setBusinessId(businessId);
        bspqce.setToken(getToken());
        CyPersistModel data = bSpaceServiceImpl.remove(bspqce);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @ApiOperation(value = "修改", notes = "修改")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{id:\\w+}")
    public CyResult update(@Valid BSpace bSpace, BindingResult bindingCyResult) {
        bSpace.setToken(getToken());
        CyPersistModel data = bSpaceServiceImpl.merge(bSpace);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bSpace);
    }

    @ApiOperation(value = "查看单 ", notes = "查看单 ")
    @GetMapping("/detail/{id:\\w+}")
    public CyResult detail(@PathVariable String id) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bSpaceServiceImpl.findById(id));
    }

    /**
     * @param bSpace
     * @return org.rcisoft.common.model.CyGridModel
     * @author ningxy
     * @description 不分页查询空间
     * @date 2018/7/20 下午1:35
     */
    @ApiOperation(value = "查看  集合 不分页", notes = "查看  集合")
    @GetMapping(value = "/queryBSpace")
    public CyResult listAllSpaces(BSpace bSpace) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,bSpaceServiceImpl.listAllSpaces(bSpace));
    }

}
