package org.rcisoft.business.bspace.service.impl;

import org.apache.commons.lang3.StringUtils;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.result.CyResultServiceExceptionEnums;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.business.bspace.dao.BSpaceRepository;
import org.rcisoft.business.bspace.entity.BSpace;
import org.rcisoft.business.bspace.service.BSpaceService;


import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import java.util.*;

import lombok.extern.slf4j.Slf4j;


/**
 * Created by  on 2018-6-21 17:10:54.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
@ConfigurationProperties(prefix = "cy.model.security", ignoreUnknownFields = true,ignoreInvalidFields = true)
public class BSpaceServiceImpl implements BSpaceService {

    @Autowired
    private BSpaceRepository bSpaceRepository;

    /**
     * 保存 bSpace
     * @param bSpace
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel save(BSpace bSpace){
        //增加操作
        CyUserUtil.setCurrentPersistOperation(bSpace);
        int line = bSpaceRepository.insertSelective(bSpace);
        log.info(CyUserUtil.getUserInfoProp(bSpace.getToken(),CyUserUtil.USER_USERNAME)+"新增了ID为"+
                bSpace.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除
     * @param bSpace
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(BSpace bSpace){
        CyUserUtil.setCurrentMergeOperation(bSpace);
        bSpace.setDeleted();
        int line = bSpaceRepository.logicalDelete(bSpace);
        log.info(CyUserUtil.getUserInfoProp(bSpace.getToken(),CyUserUtil.USER_USERNAME)+"逻辑删除了ID为"+
                bSpace.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 bSpace
     * @param bSpace
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(BSpace bSpace){
        CyUserUtil.setCurrentMergeOperation(bSpace);
        int line = bSpaceRepository.updateByPrimaryKeySelective(bSpace);
        log.info(CyUserUtil.getUserInfoProp(bSpace.getToken(),CyUserUtil.USER_USERNAME)+"修改了ID为"+
                bSpace.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 bSpace
     * @param id
     * @return
     */
    @Override
    public BSpace findById(String id){
        return bSpaceRepository.selectByPrimaryKey(id);
    }

    /**
     * 分页查询 bSpace
     * @param bSpace
     * @return
     */
    @Override
    public List<BSpace> findAllByPagination(CyPageUtil<BSpace> paginationUtility,
                                            BSpace bSpace){
        bSpace.setStart();
        bSpace.setNotDeleted();
        return bSpaceRepository.queryBSpaces(bSpace);
    }

    /**
     * @param bSpace
     * @return java.util.List<org.rcisoft.business.bspace.entity.BSpace>
     * @author ningxy
     * @description 不分页查询所有空间
     * @date 2018/7/20 下午1:36
     */
    @Override
    public List<BSpace> listAllSpaces(BSpace bSpace) {
        return bSpaceRepository.queryBSpaces(bSpace);
    }

    /**
     * 增加
     *
     * */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public int persistSpaceList(BSpace spaceList, String token ) {
        int line;
        int line2=0;
        int result = 0;
        if(StringUtils.isNotBlank(spaceList.getBusinessId())){//修改
            List<BSpace> spaceLists = bSpaceRepository.querySpaceListsByName(spaceList);

            if(spaceLists.size() == 0){
                throw new CyServiceException(CyResultServiceExceptionEnums.USER_EXISTS);
            }
//            Example example = new Example(BCategory.class);
//            example.createCriteria().andEqualTo("spaceId",spaceList.getBusinessId());
//            BCategory bcategory = new BCategory();
            CyUserUtil.setCurrentMergeOperation(spaceList);

//            bcategory.setCategoryName(spaceList.getSpaceName());
//            bcategory.setSpaceId(spaceList.getBusinessId());
            line = bSpaceRepository.updateByPrimaryKeySelective(spaceList);
//            line2 = bCategoryRepository.updateByExampleSelective(bcategory,example);

        }else{//增加
            List<BSpace> spaceLists = bSpaceRepository.querySpaceListsByCodeOrName(spaceList);
            if(spaceLists.size()>0){
                throw new CyServiceException(CyResultServiceExceptionEnums.USER_EXISTS);
            }
//            BCategory bcategory = new BCategory();
//            CyUserUtil.setCurrentPersistOperation(spaceList);
//            CyUserUtil.setCurrentPersistOperation(bcategory);
//            bcategory.setSpaceId(spaceList.getBusinessId());
//            bcategory.setCategoryName(spaceList.getSpaceName());
//            bcategory.setPid(0);
            line = bSpaceRepository.insertSelective(spaceList);
//            line2 = bCategoryRepository.insertSelective(bcategory);
        }
//        if(line == line2){
//            result = line;
//        }

        return line;

    }

    /**
     * 通过businessId查询
     * @param businessId
     * @return
     */
    @Override
    public BSpace querySpaceListByBusinessId(String businessId) {
        return bSpaceRepository.querySpaceListByBusinessId(businessId);
    }

    @Override
    public List<BSpace> querySpaceListsByPagination(CyPageUtil<BSpace> paginationUtility, BSpace spaceList) {
        return bSpaceRepository.queryBSpaceCategorys(spaceList);
    }

    /**
     * 查询空间数
     * @param spaceList
     * @return
     */
    @Override
    public List<BSpace> querySpaceNum(BSpace spaceList) {
        return bSpaceRepository.querySpaceNum(spaceList);
    }

}
